@@ -107,7 +107,7 @@ class CodeBlock(Directive):
         if linespec:
             try:
                 nlines = len(self.content)
-                hl_lines = [x+1 for x in parselinenos(linespec, nlines)]
+                hl_lines = [x + 1 for x in parselinenos(linespec, nlines)]
             except ValueError as err:
                 document = self.state.document
                 return [document.reporter.warning(str(err), line=self.lineno)]
@@ -266,7 +266,7 @@ class LiteralInclude(Directive):
                     'Object named %r not found in include file %r' %
                     (objectname, filename), line=self.lineno)]
             else:
-                lines = lines[tags[objectname][1]-1: tags[objectname][2]-1]
+                lines = lines[tags[objectname][1] - 1: tags[objectname][2] - 1]
                 if 'lineno-match' in self.options:
                     linenostart = tags[objectname][1]
 
@@ -298,7 +298,7 @@ class LiteralInclude(Directive):
         linespec = self.options.get('emphasize-lines')
         if linespec:
             try:
-                hl_lines = [x+1 for x in parselinenos(linespec, len(lines))]
+                hl_lines = [x + 1 for x in parselinenos(linespec, len(lines))]
             except ValueError as err:
                 return [document.reporter.warning(str(err), line=self.lineno)]
         else:
@@ -383,3 +383,9 @@ def setup(app):
     directives.register_directive('code-block', CodeBlock)
     directives.register_directive('sourcecode', CodeBlock)
     directives.register_directive('literalinclude', LiteralInclude)
+
+    return {
+        'version': 'builtin',
+        'parallel_read_safe': True,
+        'parallel_write_safe': True,
+    }
