@@ -29,29 +29,22 @@ from __future__ import print_function
 import time
 import zlib
 import codecs
+import functools
 import posixpath
 from os import path
 import re
 
 from six import iteritems, string_types
-from six.moves.urllib import parse, request
+from six.moves.urllib.parse import urlsplit, urlunsplit
 from docutils import nodes
 from docutils.utils import relative_path
 
 import sphinx
 from sphinx.locale import _
 from sphinx.builders.html import INVENTORY_FILENAME
+from sphinx.util import requests
 
 
-default_handlers = [request.ProxyHandler(), request.HTTPRedirectHandler(),
-                    request.HTTPHandler()]
-try:
-    default_handlers.append(request.HTTPSHandler)
-except AttributeError:
-    pass
-
-default_opener = request.build_opener(*default_handlers)
-
 UTF8StreamReader = codecs.lookup('utf-8')[2]
 
 
@@ -76,7 +69,7 @@ def read_inventory_v1(f, uri, join):
     return invdata
 
 
-def read_inventory_v2(f, uri, join, bufsize=16*1024):
+def read_inventory_v2(f, uri, join, bufsize=16 * 1024):
     invdata = {}
     line = f.readline()
     projname = line.rstrip()[11:].decode('utf-8')
@@ -99,13 +92,13 @@ def read_inventory_v2(f, uri, join, bufsize=16*1024):
             lineend = buf.find(b'\n')
             while lineend != -1:
                 yield buf[:lineend].decode('utf-8')
-                buf = buf[lineend+1:]
+                buf = buf[lineend + 1:]
                 lineend = buf.find(b'\n')
         assert not buf
 
     for line in split_lines(read_chunks()):
         # be careful to handle names with embedded spaces correctly
-        m = re.match(r'(?x)(.+?)\s+(\S*:\S*)\s+(\S+)\s+(\S+)\s+(.*)',
+        m = re.match(r'(?x)(.+?)\s+(\S*:\S*)\s+(-?\d+)\s+(\S+)\s+(.*)',
                      line.rstrip())
         if not m:
             continue
@@ -124,6 +117,14 @@ def read_inventory_v2(f, uri, join, bufsize=16*1024):
     return invdata
 
 
+def read_inventory(f, uri, join, bufsize=16 * 1024):
+    line = f.readline().rstrip().decode('utf-8')
+    if line == '# Sphinx inventory version 1':
+        return read_inventory_v1(f, uri, join)
+    elif line == '# Sphinx inventory version 2':
+        return read_inventory_v2(f, uri, join, bufsize=bufsize)
+
+
 def _strip_basic_auth(url):
     """Returns *url* with basic auth credentials removed. Also returns the
     basic auth username and password if they're present in *url*.
@@ -135,30 +136,17 @@ def _strip_basic_auth(url):
     :param url: url which may or may not contain basic auth credentials
     :type url: ``str``
 
-    :return: 3-``tuple`` of:
-
-      * (``str``) -- *url* with any basic auth creds removed
-      * (``str`` or ``NoneType``) -- basic auth username or ``None`` if basic
-        auth username not given
-      * (``str`` or ``NoneType``) -- basic auth password or ``None`` if basic
-        auth password not given
-
-    :rtype: ``tuple``
+    :return: *url* with any basic auth creds removed
+    :rtype: ``str``
     """
-    url_parts = parse.urlsplit(url)
-    username = url_parts.username
-    password = url_parts.password
-    frags = list(url_parts)
+    frags = list(urlsplit(url))
     # swap out "user[:pass]@hostname" for "hostname"
-    if url_parts.port:
-        frags[1] = "%s:%s" % (url_parts.hostname, url_parts.port)
-    else:
-        frags[1] = url_parts.hostname
-    url = parse.urlunsplit(frags)
-    return (url, username, password)
+    if '@' in frags[1]:
+        frags[1] = frags[1].split('@')[1]
+    return urlunsplit(frags)
 
 
-def _read_from_url(url):
+def _read_from_url(url, config=None):
     """Reads data from *url* with an HTTP *GET*.
 
     This function supports fetching from resources which use basic HTTP auth as
@@ -174,48 +162,38 @@ def _read_from_url(url):
     :return: data read from resource described by *url*
     :rtype: ``file``-like object
     """
-    url, username, password = _strip_basic_auth(url)
-    if username is not None and password is not None:
-        # case: url contains basic auth creds
-        password_mgr = request.HTTPPasswordMgrWithDefaultRealm()
-        password_mgr.add_password(None, url, username, password)
-        handler = request.HTTPBasicAuthHandler(password_mgr)
-        opener = request.build_opener(*(default_handlers + [handler]))
-    else:
-        opener = default_opener
-
-    return opener.open(url)
+    r = requests.get(url, stream=True, config=config, timeout=config.intersphinx_timeout)
+    r.raise_for_status()
+    r.raw.url = r.url
+    # decode content-body based on the header.
+    # ref: https://github.com/kennethreitz/requests/issues/2155
+    r.raw.read = functools.partial(r.raw.read, decode_content=True)
+    return r.raw
 
 
 def _get_safe_url(url):
     """Gets version of *url* with basic auth passwords obscured. This function
     returns results suitable for printing and logging.
 
-    E.g.: https://user:12345@example.com => https://user:********@example.com
-
-    .. note::
-
-       The number of astrisks is invariant in the length of the basic auth
-       password, so minimal information is leaked.
+    E.g.: https://user:12345@example.com => https://user@example.com
 
     :param url: a url
     :type url: ``str``
 
-    :return: *url* with password obscured
+    :return: *url* with password removed
     :rtype: ``str``
     """
-    safe_url = url
-    url, username, _ = _strip_basic_auth(url)
-    if username is not None:
-        # case: url contained basic auth creds; obscure password
-        url_parts = parse.urlsplit(url)
-        safe_netloc = '{0}@{1}'.format(username, url_parts.hostname)
-        # replace original netloc w/ obscured version
-        frags = list(url_parts)
-        frags[1] = safe_netloc
-        safe_url = parse.urlunsplit(frags)
+    parts = urlsplit(url)
+    if parts.username is None:
+        return url
+    else:
+        frags = list(parts)
+        if parts.port:
+            frags[1] = '{0}@{1}:{2}'.format(parts.username, parts.hostname, parts.port)
+        else:
+            frags[1] = '{0}@{1}'.format(parts.username, parts.hostname)
 
-    return safe_url
+        return urlunsplit(frags)
 
 
 def fetch_inventory(app, uri, inv):
@@ -225,11 +203,10 @@ def fetch_inventory(app, uri, inv):
     localuri = '://' not in uri
     if not localuri:
         # case: inv URI points to remote resource; strip any existing auth
-        uri, _, _ = _strip_basic_auth(uri)
-    join = localuri and path.join or posixpath.join
+        uri = _strip_basic_auth(uri)
     try:
         if '://' in inv:
-            f = _read_from_url(inv)
+            f = _read_from_url(inv, config=app.config)
         else:
             f = open(path.join(app.srcdir, inv), 'rb')
     except Exception as err:
@@ -237,25 +214,19 @@ def fetch_inventory(app, uri, inv):
                  '%s: %s' % (inv, err.__class__, err))
         return
     try:
-        if hasattr(f, 'geturl'):
-            newuri = f.geturl()
-            if newuri.endswith("/" + INVENTORY_FILENAME):
-                newuri = newuri[:-len(INVENTORY_FILENAME) - 1]
-            if uri != newuri and uri != newuri + "/":
-                app.info('intersphinx inventory has moved: %s -> %s' % (uri, newuri))
-                uri = newuri
-        line = f.readline().rstrip().decode('utf-8')
-        try:
-            if line == '# Sphinx inventory version 1':
-                invdata = read_inventory_v1(f, uri, join)
-            elif line == '# Sphinx inventory version 2':
-                invdata = read_inventory_v2(f, uri, join)
-            else:
-                raise ValueError
-            f.close()
-        except ValueError:
-            f.close()
-            raise ValueError('unknown or unsupported inventory version')
+        if hasattr(f, 'url'):
+            newinv = f.url
+            if inv != newinv:
+                app.info('intersphinx inventory has moved: %s -> %s' % (inv, newinv))
+
+                if uri in (inv, path.dirname(inv), path.dirname(inv) + '/'):
+                    uri = path.dirname(newinv)
+        with f:
+            try:
+                join = localuri and path.join or posixpath.join
+                invdata = read_inventory(f, uri, join)
+            except ValueError as exc:
+                raise ValueError('unknown or unsupported inventory version: %r' % exc)
     except Exception as err:
         app.warn('intersphinx inventory %r not readable due to '
                  '%s: %s' % (inv, err.__class__.__name__, err))
@@ -275,7 +246,7 @@ def load_mappings(app):
     cache = env.intersphinx_cache
     update = False
     for key, value in iteritems(app.config.intersphinx_mapping):
-        if isinstance(value, tuple):
+        if isinstance(value, (list, tuple)):
             # new format
             name, (uri, inv) = key, value
             if not isinstance(name, string_types):
@@ -365,7 +336,7 @@ def missing_reference(app, env, node, contnode):
             proj, version, uri, dispname = inventory[objtype][target]
             if '://' not in uri and node.get('refdoc'):
                 # get correct path in case of subdirectories
-                uri = path.join(relative_path(node['refdoc'], env.srcdir), uri)
+                uri = path.join(relative_path(node['refdoc'], '.'), uri)
             newnode = nodes.reference('', '', internal=False, refuri=uri,
                                       reftitle=_('(in %s v%s)') % (proj, version))
             if node.get('refexplicit'):
@@ -375,9 +346,9 @@ def missing_reference(app, env, node, contnode):
                     (domain == 'std' and node['reftype'] == 'keyword'):
                 # use whatever title was given, but strip prefix
                 title = contnode.astext()
-                if in_set and title.startswith(in_set+':'):
-                    newnode.append(contnode.__class__(title[len(in_set)+1:],
-                                                      title[len(in_set)+1:]))
+                if in_set and title.startswith(in_set + ':'):
+                    newnode.append(contnode.__class__(title[len(in_set) + 1:],
+                                                      title[len(in_set) + 1:]))
                 else:
                     newnode.append(contnode)
             else:
@@ -393,6 +364,7 @@ def missing_reference(app, env, node, contnode):
 def setup(app):
     app.add_config_value('intersphinx_mapping', {}, True)
     app.add_config_value('intersphinx_cache_limit', 5, False)
+    app.add_config_value('intersphinx_timeout', None, False)
     app.connect('missing-reference', missing_reference)
     app.connect('builder-inited', load_mappings)
     return {'version': sphinx.__display_version__, 'parallel_read_safe': True}
