@@ -12,9 +12,13 @@ from __future__ import absolute_import
 
 from copy import copy
 from contextlib import contextmanager
+import docutils
 from docutils.parsers.rst import directives, roles
 
 
+__version_info__ = tuple(map(int, docutils.__version__.split('.')))
+
+
 @contextmanager
 def docutils_namespace():
     """Create namespace for reST parsers."""
